@@ -13,6 +13,7 @@ module Temple
   autoload :ImmutableMap,         'temple/map'
   autoload :MutableMap,           'temple/map'
   autoload :OptionMap,            'temple/map'
+  autoload :StaticAnalyzer,       'temple/static_analyzer'
 
   module Mixins
     autoload :Dispatcher,         'temple/mixins/dispatcher'
@@ -43,7 +44,9 @@ module Temple
     autoload :CodeMerger,         'temple/filters/code_merger'
     autoload :ControlFlow,        'temple/filters/control_flow'
     autoload :MultiFlattener,     'temple/filters/multi_flattener'
+    autoload :StaticAnalyzer,     'temple/filters/static_analyzer'
     autoload :StaticMerger,       'temple/filters/static_merger'
+    autoload :StringSplitter,     'temple/filters/string_splitter'
     autoload :DynamicInliner,     'temple/filters/dynamic_inliner'
     autoload :Escapable,          'temple/filters/escapable'
     autoload :Eraser,             'temple/filters/eraser'
