@@ -24,7 +24,7 @@ module Temple
   #     replace :ArrayBuffer, Temple::Generators::RailsOutputBuffer
   #   end
   #
-  #   engine = MyEngine.new(:strict => "For MyParser")
+  #   engine = MyEngine.new(strict: "For MyParser")
   #   engine.call(something)
   #
   # @api public
@@ -33,7 +33,7 @@ module Temple
     include Mixins::EngineDSL
     extend  Mixins::EngineDSL
 
-    define_options :file, :streaming, :buffer
+    define_options :file, :streaming, :buffer, :save_buffer
 
     attr_reader :chain
 
@@ -57,7 +57,11 @@ module Temple
     end
 
     def call_chain
-      @call_chain ||= @chain.map {|name, constructor| constructor.call(self) }.compact
+      @call_chain ||= @chain.map do |name, constructor|
+        f = constructor.call(self)
+        raise "Constructor #{name} must return callable object" if f && !f.respond_to?(:call)
+        f
+      end.compact
     end
   end
 end
